from typing import NamedTuple, List, Dict
from pscr_common.api.models import (
    with_swagger_definition,
    with_from_dict,
    ValidationError,
)


@with_swagger_definition
@with_from_dict
class Retention(NamedTuple):
    retention_days: int

    @staticmethod
    def _validate(retention):
        if retention.retention_days < 0:
            raise ValidationError("retention_days must be greater than 0")


@with_swagger_definition
@with_from_dict
class RetentionConfig(NamedTuple):
    org: str
    retention_class: str
    retention_days: int


@with_swagger_definition
@with_from_dict
class OrgConfig(NamedTuple):
    current: Dict[str, Retention]
    defaults: Dict[str, Retention]
    allowed_days: Dict[str, List[int]]
