from configparser import ExtendedInterpolation, RawConfigParser
import os

import rapidjson as json


class Config(RawConfigParser):
    _DEFAULT_INTERPOLATION = ExtendedInterpolation()

    def __init__(self) -> None:
        super().__init__(allow_no_value=True)
        self.optionxform = str  # Use case-sensitive strings for option names
        self.read(
            os.path.join(
                os.path.dirname(os.path.abspath(__file__)), "../orgretention.ini"
            )
        )
        # Load ECS metadata
        metadata_file = os.environ.get("ECS_CONTAINER_METADATA_FILE")
        self._ecs_metadata = json.load(open(metadata_file)) if metadata_file else None

    def get(self, section, option, **kwargs):
        # Return environment variable for section/option if exists
        env_var = self._get_env_var(f"{section}.{option}")
        if env_var in os.environ:
            return os.environ[env_var]

        return super(Config, self).get(section, option, **kwargs)

    def getlist(self, section, option, **kwargs):
        return self.get(section, option, **kwargs).split(",")

    def getints(self, section, option, **kwargs):
        return list(map(int, self.getlist(section, option, **kwargs)))

    def _get_env_var(self, section_option):
        return section_option.replace(".", "_").upper()

    @property
    def ecs_metadata(self):
        return self._ecs_metadata
