import asyncio
import logging

from aio_pyformance.reporters.reporter import Reporter

from org_retention.utils.background_task import BackgroundTask

_logger = logging.getLogger(__name__)


class MetricReporterTask(BackgroundTask):
    def __init__(self, metric_reporter: Reporter):
        super(MetricReporterTask, self).__init__("metric_reporter")
        self.metric_reporter = metric_reporter
        self.sleep_target = (
            self.metric_reporter.clock.time()
            + self.metric_reporter.reporting_interval_sec
        )

    async def execute(self, app):
        try:
            await asyncio.sleep(
                max(0.0, self.sleep_target - self.metric_reporter.clock.time())
            )
            await self.metric_reporter.report_now(self.metric_reporter.registry)
        finally:
            self.sleep_target += self.metric_reporter.reporting_interval_sec
