from typing import Dict, List, Any


class Tags:
    def __init__(self, **tags) -> None:
        """Create tags loosely from any incoming parameters"""
        self.tags = tags

    def __eq__(self, other):
        return self.tags == other.tags

    @classmethod
    def from_tag_set(cls, tag_set):
        """Create Tags object from TagSet result"""
        return cls(**{t["Key"]: t["Value"] for t in tag_set})

    def __getattribute__(self, name: str) -> Any:
        """Loosely return matching tags or None"""
        try:
            return super().__getattribute__(name)
        except:
            return self.tags.get(name)

    def to_tag_set(self) -> Dict[str, List[Dict[str, str]]]:
        """Return TagSet dict format used in boto3#put_object_tagging"""
        return {"TagSet": [{"Key": t[0], "Value": t[1]} for t in self.tags.items()]}

    def to_str(self) -> str:
        """Return query params string used in boto3#put_object"""
        return "&".join(["=".join(t) for t in self.tags.items()])
